tfimport

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2020 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Overview

Code generated by go generate; DO NOT EDIT.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Add

func Add(mgr manager.Manager) error

Add creates a new Import Controller and adds it to the Manager. The Manager will set fields on the Controller and Start it when the Manager is Started.

Types

type ReconcileImport

type ReconcileImport struct {
	// contains filtered or unexported fields
}

ReconcileImport reconciles a Imp object

func (*ReconcileImport) Reconcile

func (r *ReconcileImport) Reconcile(request reconcile.Request) (reconcile.Result, error)

Reconcile reads that state of the cluster for a Imp object and makes changes based on the state read and what is in the Imp.Spec Note: The Controller will requeue the Request to be processed again if the returned error is non-nil or Result.Requeue is true, otherwise upon completion it will remove the work from the queue.

Jump to